==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DAbruptStmt.h <==
// public class soot.dava.internal.javaRep.DAbruptStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 467e9fbb02099ed2 soot_dava_internal_javaRep_DAbruptStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_dava_internal_javaRep_DAbruptStmt_H_
#define _JC_soot_dava_internal_javaRep_DAbruptStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs	_jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs	_jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$refs	_jc_soot_dava_internal_javaRep_DAbruptStmt$refs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs	_jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object	_jc_soot_dava_internal_javaRep_DAbruptStmt$object;

typedef const struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods	_jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtable	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtype	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DAbruptStmt$method$_init$e6c0b23a2df2d512(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *, struct _jc_java_lang_String$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);

// Virtual methods
extern jboolean _jc_soot_dava_internal_javaRep_DAbruptStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DAbruptStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
extern jboolean _jc_soot_dava_internal_javaRep_DAbruptStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
extern jboolean _jc_soot_dava_internal_javaRep_DAbruptStmt$method$is__5fContinue$d0ad3c2bb5e3444a(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DAbruptStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
extern void _jc_soot_dava_internal_javaRep_DAbruptStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$is__5fContinue$d0ad3c2bb5e3444a;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods {
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
	jboolean	(*is__5fContinue$d0ad3c2bb5e3444a)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods	soot_dava_internal_javaRep_DAbruptStmt;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs {
	struct _jc_java_lang_String$object	*command;
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*label;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$refs {
    _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs	soot_dava_internal_javaRep_DAbruptStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs {
	jboolean	surpressDestinationLabel;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs	soot_dava_internal_javaRep_DAbruptStmt;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object {
	_jc_soot_dava_internal_javaRep_DAbruptStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DAbruptStmt$vtype _jc_soot_dava_internal_javaRep_DAbruptStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DAbruptStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DAbruptStmt$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DAbruptStmt_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DAbruptStmt.h <==
// public class soot.dava.internal.javaRep.DAbruptStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 467e9fbb02099ed2 soot_dava_internal_javaRep_DAbruptStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_dava_internal_javaRep_DAbruptStmt_H_
#define _JC_soot_dava_internal_javaRep_DAbruptStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs	_jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs	_jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$refs	_jc_soot_dava_internal_javaRep_DAbruptStmt$refs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs	_jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object	_jc_soot_dava_internal_javaRep_DAbruptStmt$object;

typedef const struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods	_jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtable	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtype	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DAbruptStmt$method$_init$e6c0b23a2df2d512(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *, struct _jc_java_lang_String$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_dava_internal_javaRep_DAbruptStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DAbruptStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_javaRep_DAbruptStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_javaRep_DAbruptStmt$method$is__5fContinue$d0ad3c2bb5e3444a(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DAbruptStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DAbruptStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$is__5fContinue$d0ad3c2bb5e3444a;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DAbruptStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods {
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
	jboolean	(*is__5fContinue$d0ad3c2bb5e3444a)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$vmethods	soot_dava_internal_javaRep_DAbruptStmt;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs {
	struct _jc_java_lang_String$object	*command;
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*label;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$refs {
    _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_refs	soot_dava_internal_javaRep_DAbruptStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs {
	jboolean	surpressDestinationLabel;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_dava_internal_javaRep_DAbruptStmt$sub_nonrefs	soot_dava_internal_javaRep_DAbruptStmt;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object {
	_jc_soot_dava_internal_javaRep_DAbruptStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DAbruptStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DAbruptStmt$vtype _jc_soot_dava_internal_javaRep_DAbruptStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DAbruptStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DAbruptStmt$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DAbruptStmt_H_ */
